summaryrefslogtreecommitdiffhomepage
path: root/app/app.js
diff options
context:
space:
mode:
Diffstat (limited to 'app/app.js')
-rw-r--r--app/app.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/app/app.js b/app/app.js
index 1e56830880..f0fa27e4f1 100644
--- a/app/app.js
+++ b/app/app.js
@@ -24,14 +24,14 @@ const store = configureStore(initialState, memoryHistory);
const backend = new Backend(store);
// reset login state if user quit the app during login
-if((['connecting', 'failed']: Array<LoginState>).includes(store.getState().account.status)) {
+if((['logging in', 'failed']: Array<LoginState>).includes(store.getState().account.status)) {
store.dispatch(accountActions.loginChange({
status: 'none'
}));
}
-// reset connection state if user quit the app when connecting
-if(store.getState().connection.status === 'connecting') {
+// reset connection state if user quit the app when logging in
+if(store.getState().connection.status === 'logging in') {
store.dispatch(connectionActions.connectionChange({
status: 'disconnected'
}));